@@ -117,7 +117,7 @@ impl Translator for Base64Translator {
     fn parse(&self, args: &[Token], streams: &[InputStream]) -> Option<CommandArgs> {
         if args
             .iter()
-            .any(|arg| arg.tag == "command:base64" && normalized_eq(arg.as_utf8(), &["Base64"], 0))
+            .any(|arg| arg.tag == "command:base64" && normalized_eq(arg.as_str(), &["Base64"], 0))
         {
             let input = args
                 .iter()
@@ -216,6 +216,7 @@ impl Command for Base64Command {
                 Ok(Output {
                     title: "Base64 Decoder".into(),
                     blocks,
+                    ..Default::default()
                 })
             }
             Mode::Encode => Ok(Output {
@@ -226,6 +227,7 @@ impl Command for Base64Command {
                     .chain(streams)
                     .map(|data| Block::Data(block::Data::new().set_text_data(base64::encode(data))))
                     .collect(),
+                ..Default::default()
             }),
         }
     }
