@@ -64,14 +64,14 @@ impl Translator for NanoIdTranslator {
     fn parse(&self, args: &[Token], _streams: &[InputStream]) -> Option<CommandArgs> {
         if !args
             .iter()
-            .any(|arg| arg.tag == "command:nanoid" && normalized_eq(arg.as_utf8(), &["NanoID"], 0))
+            .any(|arg| arg.tag == "command:nanoid" && normalized_eq(arg.as_str(), &["NanoID"], 0))
         {
             return None;
         }
         let count = args
             .iter()
             .find(|arg| arg.tag == "input:count")
-            .and_then(|arg| arg.as_utf8().parse::<usize>().ok())
+            .and_then(|arg| arg.as_str().parse::<usize>().ok())
             .unwrap_or(1);
         Some(CommandArgs::new().add_args(["-n".to_string(), count.to_string()]))
     }
@@ -97,6 +97,7 @@ impl Command for NanoIdCommand {
                     "Too large number of the requested NanoIDs (Limit: {}).",
                     MAX_COUNT
                 )))],
+                ..Default::default()
             }
             .into());
         }
@@ -113,6 +114,7 @@ impl Command for NanoIdCommand {
                 ))),
                 Block::Data(block::Data::new().set_text_data(list.join("\n"))),
             ],
+            ..Default::default()
         })
     }
 }
